phylo4-class: The phylo4 class
Description
Classes for phylogenetic treesObjects from the Class
Phylogenetic tree objects can be created by calls to the phylo4 constructor function.
Translation functions from other phylogenetic packages are also available. See coerce-methods.See Also
The phylo4 constructor, the checkPhylo4
function to check the validity of phylo4 objects. See also the
phylo4d constructor and the phylo4d
class.